From 4efd80aa8a99adbb38d0719ba56b07c9970793b5 Mon Sep 17 00:00:00 2001
From: Ciro Santilli <ciro.santilli@gmail.com>
Date: Tue, 4 Aug 2015 09:03:15 -0700
Subject: python: fix Linetable case to LineTable in docstrings and comments

The class is called LineTable, not Linetable, as specified by
py-linetable.c/gdbpy_initialize_linetable:

    if (gdb_pymodule_addobject (gdb_module, "LineTable",

gdb/ChangeLog:

        * python/py-linetable.c: Fix case of Linetable to LineTable
        in docstrings and code comments.
        * python/py-symtab.c: Same.
---
 gdb/python/py-linetable.c | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

(limited to 'gdb/python/py-linetable.c')

diff --git a/gdb/python/py-linetable.c b/gdb/python/py-linetable.c
index 82b4cfc..ff4414e 100644
--- a/gdb/python/py-linetable.c
+++ b/gdb/python/py-linetable.c
@@ -55,7 +55,7 @@ typedef struct {
 extern PyTypeObject ltpy_iterator_object_type
     CPYCHECKER_TYPE_OBJECT_FOR_TYPEDEF ("ltpy_iterator_object");
 
 /* Internal helper function to extract gdb.Symtab from a gdb.Linetable
    object.  */
 
 static PyObject *
@@ -288,7 +288,7 @@ ltpy_get_all_source_lines (PyObject *self, PyObject *args)
   return source_list;
 }
 
 /* Implementation of gdb.Linetable.is_valid (self) -> Boolean.
    Returns True if this line table object still exists in GDB.  */
 
 static PyObject *
@@ -349,7 +349,7 @@ gdbpy_initialize_linetable (void)
   return 0;
 }
 
 /* Linetable entry object get functions.  */
 
 /* Implementation of gdb.LineTableEntry.line (self) -> Long.  Returns
    a long integer associated with the line table entry.  */
@@ -373,7 +373,7 @@ ltpy_entry_get_pc (PyObject *self, void *closure)
   return  gdb_py_object_from_longest (obj->pc);
 }
 
 /* Linetable iterator functions.  */
 
 /* Return a new line table iterator.  */
 
@@ -460,7 +460,7 @@ ltpy_iternext (PyObject *self)
   return NULL;
 }
 
 /* Implementation of gdb.LinetableIterator.is_valid (self) -> Boolean.
    Returns True if this line table iterator object still exists in
    GDB.  */
 
@@ -492,7 +492,7 @@ Return TRUE if this line has executable information, FALSE if not." },
 Return a list of all executable source lines." },
   { "is_valid", ltpy_is_valid, METH_NOARGS,
     "is_valid () -> Boolean.\n\
-Return True if this Linetable is valid, False if not." },
+Return True if this LineTable is valid, False if not." },
   {NULL}  /* Sentinel */
 };
 
@@ -539,7 +539,7 @@ PyTypeObject linetable_object_type = {
 static PyMethodDef ltpy_iterator_methods[] = {
   { "is_valid", ltpy_iter_is_valid, METH_NOARGS,
     "is_valid () -> Boolean.\n\
-Return True if this Linetable iterator is valid, False if not." },
+Return True if this LineTable iterator is valid, False if not." },
   {NULL}  /* Sentinel */
 };
 
@@ -55,7 +55,7 @@ typedef struct {
     CPYCHECKER_TYPE_OBJECT_FOR_TYPEDEF ("ltpy_iterator_object");
 
-/* Internal helper function to extract gdb.Symtab from a gdb.Linetable
+/* Internal helper function to extract gdb.Symtab from a gdb.LineTable
    object.  */
 
@@ -288,7 +288,7 @@ ltpy_get_all_source_lines (PyObject *self, PyObject *args)
 }
 
-/* Implementation of gdb.Linetable.is_valid (self) -> Boolean.
+/* Implementation of gdb.LineTable.is_valid (self) -> Boolean.
    Returns True if this line table object still exists in GDB.  */
 
@@ -349,7 +349,7 @@ gdbpy_initialize_linetable (void)
 }
 
-/* Linetable entry object get functions.  */
+/* LineTable entry object get functions.  */
 
 /* Implementation of gdb.LineTableEntry.line (self) -> Long.  Returns
@@ -373,7 +373,7 @@ ltpy_entry_get_pc (PyObject *self, void *closure)
 }
 
-/* Linetable iterator functions.  */
+/* LineTable iterator functions.  */
 
 /* Return a new line table iterator.  */
@@ -460,7 +460,7 @@ ltpy_iternext (PyObject *self)
 }
 
-/* Implementation of gdb.LinetableIterator.is_valid (self) -> Boolean.
+/* Implementation of gdb.LineTableIterator.is_valid (self) -> Boolean.
    Returns True if this line table iterator object still exists in
    GDB.  */
-- 
cgit v1.1